Crate soundcloud

SoundCloud API library

This soundcloud library provides an interface where you can query soundcloud for information about tracks and users.

Re-exports

  • pub use crate::error::Error;

Modules

Structs

Constants

  • The static host address for the API.